==> haskell-utility-ht-0.0.14-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-utility-ht.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: utility-ht
version: 0.0.14
id: utility-ht-0.0.14-24xG04xbcZ3HPMjtp2taYT
key: utility-ht-0.0.14-24xG04xbcZ3HPMjtp2taYT
license: BSD3
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
stability: Stable
synopsis: Various small helper functions for Lists, Maybes, Tuples, Functions
description:
    Various small helper functions for Lists, Maybes, Tuples, Functions.
    Some of these functions are improved implementations of standard functions.
    They have the same name as their standard counterparts.
    Others are equivalent to functions from the @base@ package,
    but if you import them from this utility package
    then you can write code that runs on older GHC versions
    or other compilers like Hugs and JHC.
    .
    All modules are plain Haskell 98.
    The package depends exclusively on the @base@ package
    and only that portions of @base@ that are simple to port.
    Thus you do not risk a dependency avalanche by importing it.
    However, further splitting the base package might invalidate this statement.
    .
    Alternative packages: @Useful@, @MissingH@
category: Data, List
author: Henning Thielemann <haskell@henning-thielemann.de>
exposed: True
exposed-modules:
    Data.Bits.HT Data.Bool.HT Data.Eq.HT Data.Function.HT Data.Ix.Enum
    Data.List.HT Data.List.Key Data.List.Match
    Data.List.Reverse.StrictElement Data.List.Reverse.StrictSpine
    Data.Maybe.HT Data.Either.HT Data.Monoid.HT Data.Ord.HT
    Data.Record.HT Data.String.HT Data.Tuple.HT Data.Tuple.Lazy
    Data.Tuple.Strict Control.Monad.HT Control.Applicative.HT
    Control.Functor.HT Data.Strictness.HT Text.Read.HT Text.Show.HT
hidden-modules: Data.Bool.HT.Private Data.List.HT.Private
                Data.List.Key.Private Data.List.Match.Private
                Data.Function.HT.Private Data.Record.HT.Private Data.Tuple.Example
abi: 3e37881b6464b9c9b938ab5e5f96262f
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/utility-ht-0.0.14
library-dirs: /usr/lib/ghc-8.0.2/site-local/utility-ht-0.0.14
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/utility-ht-0.0.14
hs-libraries: HSutility-ht-0.0.14-24xG04xbcZ3HPMjtp2taYT
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-utility-ht/html/utility-ht.haddock
haddock-html: /usr/share/doc/haskell-utility-ht/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-utility-ht-0.0.14-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-utility-ht.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: utility-ht
version: 0.0.14
id: utility-ht-0.0.14-4br28cWzxu32AcVJ156WVj
key: utility-ht-0.0.14-4br28cWzxu32AcVJ156WVj
license: BSD3
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
stability: Stable
synopsis: Various small helper functions for Lists, Maybes, Tuples, Functions
description:
    Various small helper functions for Lists, Maybes, Tuples, Functions.
    Some of these functions are improved implementations of standard functions.
    They have the same name as their standard counterparts.
    Others are equivalent to functions from the @base@ package,
    but if you import them from this utility package
    then you can write code that runs on older GHC versions
    or other compilers like Hugs and JHC.
    .
    All modules are plain Haskell 98.
    The package depends exclusively on the @base@ package
    and only that portions of @base@ that are simple to port.
    Thus you do not risk a dependency avalanche by importing it.
    However, further splitting the base package might invalidate this statement.
    .
    Alternative packages: @Useful@, @MissingH@
category: Data, List
author: Henning Thielemann <haskell@henning-thielemann.de>
exposed: True
indefinite: False
exposed-modules:
    Control.Applicative.HT Control.Functor.HT Control.Monad.HT
    Data.Bits.HT Data.Bool.HT Data.Either.HT Data.Eq.HT
    Data.Function.HT Data.Ix.Enum Data.List.HT Data.List.Key
    Data.List.Match Data.List.Reverse.StrictElement
    Data.List.Reverse.StrictSpine Data.Maybe.HT Data.Monoid.HT
    Data.Ord.HT Data.Record.HT Data.Strictness.HT Data.String.HT
    Data.Tuple.HT Data.Tuple.Lazy Data.Tuple.Strict Text.Read.HT
    Text.Show.HT
hidden-modules: Data.Bool.HT.Private Data.List.HT.Private
                Data.List.Key.Private Data.List.Match.Private
                Data.Function.HT.Private Data.Record.HT.Private Data.Tuple.Example
abi: 1a1809eb8ba2e75eb9ba0f6b65f67465
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/utility-ht-0.0.14
library-dirs: /usr/lib/ghc-8.2.1/site-local/utility-ht-0.0.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/utility-ht-0.0.14
hs-libraries: HSutility-ht-0.0.14-4br28cWzxu32AcVJ156WVj
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
haddock-interfaces: /usr/share/doc/haskell-utility-ht/html/utility-ht.haddock
haddock-html: /usr/share/doc/haskell-utility-ht/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
